@@ -8,10 +8,11 @@ urlpatterns = [
     path('finish/<slug:uuid>', views.scrobble_finish, name='finish'),
     path('cancel/<slug:uuid>', views.scrobble_cancel, name='cancel'),
     path(
-        'audioscrobbler-file-upload/',
-        views.import_audioscrobbler_file,
+        'upload/',
+        views.AudioScrobblerImportCreateView.as_view(),
         name='audioscrobbler-file-upload',
     ),
     path('jellyfin/', views.jellyfin_websocket, name='jellyfin-websocket'),
     path('mopidy/', views.mopidy_websocket, name='mopidy-websocket'),
+    path('export/', views.export, name='export'),
 ]
